==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/TRADERATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour TRADERATEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TRADERATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATEPERSON"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATESTARTDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRADERATEID_Type", propOrder = {
    "departmentid",
    "tradeid",
    "supplierid",
    "traderateperson",
    "organizationid",
    "traderatestartdate",
    "occupationtypecode"
})
public class TRADERATEID_Type {

    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "TRADEID", required = true)
    protected TRADEID_Type tradeid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "TRADERATEPERSON", required = true)
    protected String traderateperson;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "TRADERATESTARTDATE", required = true)
    protected DATETIME traderatestartdate;
    @XmlElement(name = "OCCUPATIONTYPECODE", required = true)
    protected String occupationtypecode;

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété supplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Définit la valeur de la propriété supplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Obtient la valeur de la propriété traderateperson.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRADERATEPERSON() {
        return traderateperson;
    }

    /**
     * Définit la valeur de la propriété traderateperson.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRADERATEPERSON(String value) {
        this.traderateperson = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété traderatestartdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRADERATESTARTDATE() {
        return traderatestartdate;
    }

    /**
     * Définit la valeur de la propriété traderatestartdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRADERATESTARTDATE(DATETIME value) {
        this.traderatestartdate = value;
    }

    /**
     * Obtient la valeur de la propriété occupationtypecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOCCUPATIONTYPECODE() {
        return occupationtypecode;
    }

    /**
     * Définit la valeur de la propriété occupationtypecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOCCUPATIONTYPECODE(String value) {
        this.occupationtypecode = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/TRADERATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for TRADERATEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="TRADERATEID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRADEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SUPPLIERID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRADERATEPERSON"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRADERATESTARTDATE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPECODE"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRADERATEID_Type", propOrder = {
    "departmentid",
    "tradeid",
    "supplierid",
    "traderateperson",
    "organizationid",
    "traderatestartdate",
    "occupationtypecode"
})
public class TRADERATEID_Type {

    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "TRADEID", required = true)
    protected TRADEID_Type tradeid;
    @XmlElement(name = "SUPPLIERID", required = true)
    protected SUPPLIERID_Type supplierid;
    @XmlElement(name = "TRADERATEPERSON", required = true)
    protected String traderateperson;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "TRADERATESTARTDATE", required = true)
    protected DATETIME traderatestartdate;
    @XmlElement(name = "OCCUPATIONTYPECODE", required = true)
    protected String occupationtypecode;

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the supplierid property.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getSUPPLIERID() {
        return supplierid;
    }

    /**
     * Sets the value of the supplierid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setSUPPLIERID(SUPPLIERID_Type value) {
        this.supplierid = value;
    }

    /**
     * Gets the value of the traderateperson property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRADERATEPERSON() {
        return traderateperson;
    }

    /**
     * Sets the value of the traderateperson property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRADERATEPERSON(String value) {
        this.traderateperson = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the traderatestartdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getTRADERATESTARTDATE() {
        return traderatestartdate;
    }

    /**
     * Sets the value of the traderatestartdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setTRADERATESTARTDATE(DATETIME value) {
        this.traderatestartdate = value;
    }

    /**
     * Gets the value of the occupationtypecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOCCUPATIONTYPECODE() {
        return occupationtypecode;
    }

    /**
     * Sets the value of the occupationtypecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOCCUPATIONTYPECODE(String value) {
        this.occupationtypecode = value;
    }

}
